Learn R Programming

geneRxCluster (version 1.8.0)

critVal.target: critical regions

Description

critical region cutpoints

Usage

critVal.target(k, p0, target, posdiff = NULL, ns)

Arguments

k
window width(s)
p0
length 2 probabilities
target
- two tailed
posdiff
- position difference matrix
ns
the number of windows passing filter at each k

Value

list of cutoffs and attributes

Details

This version uses TFD and will find alpha implicitly

See Also

gRxCluster for how and why this function is used

Examples

Run this code
# symmetric odds:
crit <- critVal.target(5:25,c(1,1),1,ns=rep(10,21))
crit[[1]]
sapply(crit,c)
# 5:1 odds
asymmetric.crit <- critVal.target(5:25,c(1,5),1,ns=rep(10,21))
# show the critical regions
par(mfrow=c(1,2))
gRxPlot(crit,method="critical")
gRxPlot(asymmetric.crit,method="critical")
rm(crit,asymmetric.crit)

Run the code above in your browser using DataLab