gRxCluster(...)
The object returned is a GRanges object.
If the object is x, seqnames(x) and ranges(x)
slots demarcate the clusters discovered. There will be one element for
each cluster (aka clump) discovered.
Using the default argument pruneFun=prune.loglik or
pruneFun=noprune, mcols(x) will have these
columns:
value1 and
value2x
clump.id
If the user supplies a custom pruneFun, it should return a
GRanges with those columns and one element for each unique
clump.id. The column target.min has the smallest nominal
False Discoveries Expected for each cluster and is added to (or
replaces) the mcols(x) produced by the argument supplied as
pruneFun.
metadata(x) will include these components:
critVal.target whose elements each give the cutpoints
to be used for a window with k sites.
attributes(metadata(object)$criticalValues[[i]]) will
contain elements
c(k+1,4) of target false
discovery expectations and and the one-sided p-values
In some cases, an attribute is attached to
metadata(object)$criticalValues, see
critVal.power for an example.
list whose canonical element is a vector of
values like x$target.min obtained from a permutation of the
class indicators
gRxCluster