Learn R Programming

geneRxCluster (version 1.8.0)

gRxPlot: gRxPlot

Description

Plot Clumps and/or Critical Regions

Usage

gRxPlot(object, pi.0 = NULL, method = c("odds", "criticalRegions"), xlim = NULL, main = NULL, xlab = "log odds ratio", breaks = "Sturges", kvals = NULL, ...)

Arguments

object
either the results of gRxCluster or a list containing cutpoints for critical regions.
pi.0
the background proportion for vector 2
method
character vector of “odds” and/or “criticalRegions”
xlim
limits of the log odds histogram
main
a title for the panel(s)
xlab
label fgor the x-axis of the log odds plot
breaks
see hist
kvals
values to use in selecting a subset of the critical regions to display
...
other args to pass to the plotting routine(s)

Value

see hist

Details

The results of a call to gRxCluster are plotted. Optionally, with method="criticalRegions" only the critical regions are plotted or with method="odds" the log odds only are plotted.

See Also

gRxPlotClumps for a more fine grained display

Examples

Run this code
x.seqnames <- rep(letters[1:3],each=500)
x.starts <- c(seq(1,length=500),seq(1,by=2,length=500),seq(1,by=3,length=500))
x.lens <- rep(c(5,10,15,20,25),each=20)
x.group <- rep(rep(c(TRUE,FALSE),length=length(x.lens)),x.lens)
## add a bit of fuzz:
x.group <- 1==rbinom(length(x.group),1,pr=ifelse(x.group,.8,.2))
x.kvals <- as.integer(sort(unique(x.lens)))
x.res <- gRxCluster(x.seqnames,x.starts,x.group,x.kvals)
gRxPlot(x.res)
rm( x.seqnames, x.starts, x.lens, x.group, x.kvals, x.res)

Run the code above in your browser using DataLab