Learn R Programming

geneRxCluster (version 1.8.0)

noprune: noprune

Description

join contiguous windows

Usage

noprune(x, ...)

Arguments

x
a GRanges object
...
currently unused

Value

same as gRxCluster less the metadata

Details

return all the candidate sites in a clump without pruning

this is to be used as the pruneFun are of gRxCluster

See Also

gRxCluster-object for more details on what this function returns.